@@ -1,5 +1,4 @@
 /*
- *
  *  This file is part of the kuiviewer package
  *  Copyright (c) 2003 Richard Moore <rich@kde.org>
  *  Copyright (c) 2003 Ian Reinhart Geiser <geiseri@kde.org>
@@ -18,18 +17,20 @@
  *  along with this library; see the file COPYING.LIB.  If not, write to
  *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *  Boston, MA 02110-1301, USA.
- **/
+ */
+
 #ifndef UICREATOR_H
 #define UICREATOR_H
 
-#include <kio/thumbcreator.h>
+#include <KIO/ThumbCreator>
 
 class QUICreator : public ThumbCreator
 {
 public:
     QUICreator() {}
-    virtual bool create(const QString &path, int, int, QImage &img);
-    virtual Flags flags() const;
+
+    bool create(const QString& path, int, int, QImage& img) override;
+    Flags flags() const override;
 };
 
 #endif // UICREATOR_H
